==> jc-1.4.0.tar.gz: java/awt/datatransfer/StringSelection.h <==
// public class java.awt.datatransfer.StringSelection

// class file dependencies
// @dep_class dc5f1b296c90301e java_awt_datatransfer_StringSelection
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_datatransfer_StringSelection_H_
#define _JC_java_awt_datatransfer_StringSelection_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_StringSelection$sub_refs	_jc_java_awt_datatransfer_StringSelection$sub_refs;
typedef struct _jc_java_awt_datatransfer_StringSelection$sub_nonrefs	_jc_java_awt_datatransfer_StringSelection$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_StringSelection$refs	_jc_java_awt_datatransfer_StringSelection$refs;
typedef struct _jc_java_awt_datatransfer_StringSelection$nonrefs	_jc_java_awt_datatransfer_StringSelection$nonrefs;
typedef struct _jc_java_awt_datatransfer_StringSelection$object	_jc_java_awt_datatransfer_StringSelection$object;

typedef struct _jc_java_awt_datatransfer_StringSelection$fields_struct	_jc_java_awt_datatransfer_StringSelection$fields_struct;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vmethods	_jc_java_awt_datatransfer_StringSelection$vmethods;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vtable	_jc_java_awt_datatransfer_StringSelection$vtable;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vtype	_jc_java_awt_datatransfer_StringSelection$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_StringSelection$fields_struct {
	_jc_object_array	*supported__5fflavors;
};
extern _jc_java_awt_datatransfer_StringSelection$fields_struct _jc_java_awt_datatransfer_StringSelection$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_StringSelection$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_datatransfer_StringSelection$method$getTransferData$8a1eeb30bd3ece8d(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
extern _jc_object_array *_jc_java_awt_datatransfer_StringSelection$method$getTransferDataFlavors$14e95b4571b7e923(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *);
extern jboolean _jc_java_awt_datatransfer_StringSelection$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
extern void _jc_java_awt_datatransfer_StringSelection$method$lostOwnership$a36543e35cbafd14(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$getTransferData$8a1eeb30bd3ece8d;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$getTransferDataFlavors$14e95b4571b7e923;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$isDataFlavorSupported$9e698abce62becef;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$lostOwnership$a36543e35cbafd14;

// Static methods
extern void _jc_java_awt_datatransfer_StringSelection$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_datatransfer_StringSelection$vmethods {
	struct _jc_java_lang_Object$object	*(*getTransferData$8a1eeb30bd3ece8d)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
	_jc_object_array	*(*getTransferDataFlavors$14e95b4571b7e923)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *);
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
	void	(*lostOwnership$a36543e35cbafd14)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_awt_datatransfer_StringSelection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_StringSelection$vmethods	java_awt_datatransfer_StringSelection;
};

// Vtype
struct _jc_java_awt_datatransfer_StringSelection$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_StringSelection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_StringSelection$sub_refs {
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_StringSelection$refs {
    _jc_java_awt_datatransfer_StringSelection$sub_refs	java_awt_datatransfer_StringSelection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_StringSelection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_StringSelection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_StringSelection$sub_nonrefs	java_awt_datatransfer_StringSelection;
};

// Object instance structure
struct _jc_java_awt_datatransfer_StringSelection$object {
	_jc_java_awt_datatransfer_StringSelection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_StringSelection$vtype	*vtype;
	_jc_java_awt_datatransfer_StringSelection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_StringSelection$vtype _jc_java_awt_datatransfer_StringSelection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_StringSelection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_StringSelection$class_object;

#endif	/* _JC_java_awt_datatransfer_StringSelection_H_ */

==> jc-1.4.6.tar.gz: java/awt/datatransfer/StringSelection.h <==
// public class java.awt.datatransfer.StringSelection

// class file dependencies
// @dep_class dc5f1b296c90301e java_awt_datatransfer_StringSelection
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_datatransfer_StringSelection_H_
#define _JC_java_awt_datatransfer_StringSelection_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_StringSelection$sub_refs	_jc_java_awt_datatransfer_StringSelection$sub_refs;
typedef struct _jc_java_awt_datatransfer_StringSelection$sub_nonrefs	_jc_java_awt_datatransfer_StringSelection$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_StringSelection$refs	_jc_java_awt_datatransfer_StringSelection$refs;
typedef struct _jc_java_awt_datatransfer_StringSelection$nonrefs	_jc_java_awt_datatransfer_StringSelection$nonrefs;
typedef struct _jc_java_awt_datatransfer_StringSelection$object	_jc_java_awt_datatransfer_StringSelection$object;

typedef struct _jc_java_awt_datatransfer_StringSelection$fields_struct	_jc_java_awt_datatransfer_StringSelection$fields_struct;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vmethods	_jc_java_awt_datatransfer_StringSelection$vmethods;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vtable	_jc_java_awt_datatransfer_StringSelection$vtable;
typedef const struct _jc_java_awt_datatransfer_StringSelection$vtype	_jc_java_awt_datatransfer_StringSelection$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_StringSelection$fields_struct {
	_jc_object_array	*supported__5fflavors;
};
extern _jc_java_awt_datatransfer_StringSelection$fields_struct _jc_java_awt_datatransfer_StringSelection$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_StringSelection$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_datatransfer_StringSelection$method$getTransferData$8a1eeb30bd3ece8d(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_awt_datatransfer_StringSelection$method$getTransferDataFlavors$14e95b4571b7e923(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_datatransfer_StringSelection$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_datatransfer_StringSelection$method$lostOwnership$a36543e35cbafd14(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$getTransferData$8a1eeb30bd3ece8d;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$getTransferDataFlavors$14e95b4571b7e923;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$isDataFlavorSupported$9e698abce62becef;
extern _jc_method _jc_java_awt_datatransfer_StringSelection$method_info$lostOwnership$a36543e35cbafd14;

// Static methods
extern void _jc_java_awt_datatransfer_StringSelection$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_datatransfer_StringSelection$vmethods {
	struct _jc_java_lang_Object$object	*(*getTransferData$8a1eeb30bd3ece8d)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getTransferDataFlavors$14e95b4571b7e923)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *) _JC_JCNI_ATTR;
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
	void	(*lostOwnership$a36543e35cbafd14)(_jc_env *, struct _jc_java_awt_datatransfer_StringSelection$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_datatransfer_StringSelection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_StringSelection$vmethods	java_awt_datatransfer_StringSelection;
};

// Vtype
struct _jc_java_awt_datatransfer_StringSelection$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_StringSelection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_StringSelection$sub_refs {
	struct _jc_java_lang_String$object	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_StringSelection$refs {
    _jc_java_awt_datatransfer_StringSelection$sub_refs	java_awt_datatransfer_StringSelection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_StringSelection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_StringSelection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_StringSelection$sub_nonrefs	java_awt_datatransfer_StringSelection;
};

// Object instance structure
struct _jc_java_awt_datatransfer_StringSelection$object {
	_jc_java_awt_datatransfer_StringSelection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_StringSelection$vtype	*vtype;
	_jc_java_awt_datatransfer_StringSelection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_StringSelection$vtype _jc_java_awt_datatransfer_StringSelection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_StringSelection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_StringSelection$class_object;

#endif	/* _JC_java_awt_datatransfer_StringSelection_H_ */
